Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

362 documents were found matching the selected criteria.
Page: [ 1] 2 3 4 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State ex rel. Johnson v. Franklin Cty. Mun. Court | 14AP-219 | The magistrate properly determined the pertinent facts and applied the appropriate law. Therefore, the court overrules relator’s objections to the magistrate’s decision and adopts the same. Accordingly the court grant’s the motion for summary judgment of respondent and denies the writ of mandamus. | Per Curiam | 7/29/2014 | 2014-Ohio-3308
Tucker v. Leadership Academy for Math & Science of Columbus | 14AP-100 | Trial court did not err in granting summary judgment in favor of appellee in appellant's action for declaratory and injunctive relief. | Brown | 7/29/2014 | 2014-Ohio-3307
Swihart v. Ohio Adult Parole Auth. | 13AP-993 | Defendant was not denied meaningful consideration for parole where Ohio Adult Parole Authority, following consideration of the mandatory factors set forth in Ohio Adm.Code 5120:1-1-07(B), and in the exercise of reasonable discretion, concluded that the serious nature of defendant’s offense outweighed post-incarceration behavior and accomplishments. Defendant was not entitled to furlough release or honor status | O'Grady | 7/29/2014 | 2014-Ohio-3305
Fifth Third Mtge. Co. v. Salahuddin | 13AP-945 | Because no genuine issues of material fact existed, summary judgment in favor of the plaintiff on its complaint for foreclosure was proper. Judgment affirmed. | Sadler | 7/29/2014 | 2014-Ohio-3304
Wells Fargo Bank, N.A. v. Byers | 13AP-767 | Trial court did not abuse its discretion in granting summary judgment in favor of plaintiff. | Brown | 7/29/2014 | 2014-Ohio-3303
State ex rel. Ferrolux Metals Co. of Ohio L.L.C. v. Indus. Comm. | 13AP-463 | The court overrules objections to the magistrate’s decision that he erred in interpreting State ex rel. Timmerman Truss, Inc. v. Indus. Comm., 102 Ohio St.3d 244, 2004-Ohio-2589, as applied to this case and that the order of the Industrial Commission is consistent with State ex rel Speelman v. Indus. Comm., 73 Ohio App.3d 757 (10th Dist.1992). Therefore, the court adopts the magistrate’s decision and denies the request for a writ of mandamus. | Dorrian | 7/29/2014 | 2014-Ohio-3302
Citibank N.A. v. Fornal | 11AP-300 | Appellant failed to raise the argument outlined in the appellate brief before the trial court and therefore has waived the same. Furthermore, the argument does not support the error assigned in the appellate brief. Accordingly, the court declines to address the merits, overrules the assignment of error, and affirms the judgment of the trial court. | Dorrian | 7/29/2014 | 2014-Ohio-3301
Liebling v. Columbus State Community College | 14AP-172 | Court of Claims of Ohio erred in dismissing lawsuit as moot when immunity issues remained to be addressed. | Tyack | 7/24/2014 | 2014-Ohio-3256
Franklinton Senior, L.L.C. v. Timson | 14AP-171 | Assignments of error challenging the trial court’s order of forcible entry and detainer were moot because appellant vacated the premises and immediate possession is no longer an issue. | Dorrian | 7/24/2014 | 2014-Ohio-3255
Craig v. Reynolds | 14AP-125 | We affirm the trial court’s judgment dismissing appellant’s action against appellee because appellee was not served with process in compliance with the Ohio Rules of Civil Procedure. | O'Grady | 7/24/2014 | 2014-Ohio-3254
State v. Balams | 14AP-54 | Juvenile court did not err in binding defendant over to General Division of the common pleas court. | Tyack | 7/24/2014 | 2014-Ohio-3253
State ex rel. Frazier v. Schneider | 14AP-52 | Writ of mandamus dismissed. | Brown | 7/24/2014 | 2014-Ohio-3252
State of Ohio Dept. of Dev. v. Matrix Centennial, L.L.C. | 14AP-47 | Ohio Dept. of Development could legally claw back funds provided for building project which was not completed. | Tyack | 7/24/2014 | 2014-Ohio-3251
State ex rel. Thomas v. Scott | 13AP-887 | Writ of habeas corpus denied. | Brown | 7/24/2014 | 2014-Ohio-3250
State v. Vinson | 13AP-825 | The trial court’s verdict was neither against the manifest weight of the evidence nor based on insufficient evidence. A victim’s testimony, when believed and determined to be credible, is sufficient evidence for a jury to find a defendant guilty, even where there is a lack of physical evidence. Judgment affirmed. | Schuster | 7/24/2014 | 2014-Ohio-3249
Hurst v. Atty. Gen. | 14AP-118, 14AP-152 | The Court of Claims of Ohio did not err in dismissing claims seeking damages for the imposition of erroneous sex offender classifications. | Klatt | 7/22/2014 | 2014-Ohio-3210
State ex rel. Frazier v. Schneidner | 14AP-99 | Writ of mandamus dismissed. | Brown | 7/22/2014 | 2014-Ohio-3209
State v. Jordan | 14AP-1 | Judgment affirmed. Both sufficient evidence and the manifest weight of the evidence supported defendant's robbery convictions. Even if defendant was absent when the court and counsel discussed the proper answers to the jury's questions, defendant's Crim.R. 43(A) right to be present was not violated, as the legal discussion of how to answer the jury's questions, and the jury's receipt of the written answers to those questions, were not critical stages of the trial. | Connor | 7/22/2014 | 2014-Ohio-3208
Fields v. Ohio Dept. of Rehab. & Corr. | 13AP-1079 | Competent, credible evidence supported the trial court's finding that defendant's negligent act did not proximtely cause the complained of injury, and thus, the court did not err in refusing to award damages for that injury. Also, the trial court did not err in admitting expert evidence regarding possible causes of plaintiff's injury. | Klatt | 7/22/2014 | 2014-Ohio-3207
State v. Ndiaye | 13AP-964 | Appellant’s convictions for aggravated robbery and robbery, both with firearm specification, were not against the manifest weight of the evidence, and the trial court did not err in overruling objections regarding prosecutorial misconduct. The trial court plainly erred, however, in failing to merge appellant’s convictions for sentencing. | Schuster | 7/22/2014 | 2014-Ohio-3206
Bradley v. Ohio Dept. of Transp. | 13AP-918 | Because appellant did not meet her reciprocal burden under Civ.R. 56 by timely responding to opposing party's motion for summary judgment, the trial court's granting of summary judgment was proper. | Dorrian | 7/22/2014 | 2014-Ohio-3205
State v. Isbell | 13AP-694 | Where police detect the odor of marijuana and observe a baggie of pills in plain view during the execution of a search warrant for appellant's person, and that information supplies probable cause for a subsequent search warrant, evidence of drugs, drug paraphernalia and a firearm uncovered in the subsequent search will not be excluded as fruit of the poison tree. | Connor | 7/22/2014 | 2014-Ohio-3204
Iqbal v. Wells Fargo Bank, N.A. | 14AP-31 | Judgment affirmed. Trial court did not abuse its discretion in denying plaintiff's motion for default judgment, as plaintiff had failed to perfect service on the defendant when plaintiff filed the motion for default judgment. The trial court properly granted defendant's motion for summary judgment, as plaintiff was not entitled to the insurance proceeds under the mortgage, and the letter plaintiff relied on to support his claim to the insurance proceeds was not a contract. | Connor | 7/17/2014 | 2014-Ohio-3156
State v. Ferguson | 13AP-891 | The defendant's conviction for trafficking in cocaine in an amount equal to or exceeding 27 grams but less than 100 grams was supported by sufficient evidence and was not against the manifest weight of the evidence. However, the restitution order requiring payment to the law enforcement agency for reimbursement of the money used in an undercover drug buy was improper. Judgment affirmed in part and reversed in part. | Sadler | 7/17/2014 | 2014-Ohio-3153
Hodge v. Prater | 13AP-838 | The trial court did not err in granting summary judgment in favor of appellee where the only reasonable conclusion one can draw from the evidence is that appellant breached the contract by failing to pay appellee for his representation of appellant in obtaining an insurance settlement. Trial court did not err in denying appellant's motion to continue the hearing on plaintiff's motion for summary judgment where the evidence appellant sought in discovery was not relevant to a material issue in the case. | Connor | 7/17/2014 | 2014-Ohio-3152
State v. Carroll | 13AP-968 | The evidence was sufficient to support a conviction for aggravated arson as a felony of the first degree. | Tyack | 7/15/2014 | 2014-Ohio-3107
State ex rel. Sagallah v. Born | 13AP-787 | Relator’s complaint does not properly invoke our original jurisdiction in mandamus as the real objects sought are a declaratory judgment and a prohibitory injunction, and thus we dismiss for lack of jurisdiction. | Schuster | 7/15/2014 | 2014-Ohio-3106
State v. Fielding | 13AP-654,13AP-655 | Trial court properly suppressed evidence stemming from law enforecement's obtainment of internet subscriber information through the investigative subpoena process. Convictions for pandering sexually oriented matter involving a minor supported by sufficient evidence and manifest weight of the evidence. | Brown | 7/15/2014 | 2014-Ohio-3105
State v. Chavis-Tucker | 14AP-40 | Trial court did not err by denying motion for new trial based on juror misconduct because defendant did not establish that he was unavoidably prevented from discovering the grounds for his motion. | Klatt | 7/10/2014 | 2014-Ohio-3050
Ryan v. Ryan | 14AP-28 | The trial court did not abuse its discretion in affirming the magistrate’s contempt order. Appellant had not proven by a preponderance of the evidence that he was unable to pay the sailboat debt obligation he voluntarily assumed in the parties’ divorce decree. Further, the court’s sentence did not violate the constitutional prohibition against incarceration for failure to pay a debt. Judgment affirmed. | Schuster | 7/10/2014 | 2014-Ohio-3049
State ex rel. O'Brien & Assocs., Co. L.P.A. v. Tyack | 13AP-1099 | Respondents' motion for summary judgment granted, and relators' request for writ of mandamus denied. | Brown | 7/10/2014 | 2014-Ohio-3048
Ewell v. Montgomery Cty. Court of Common Pleas | 13AP-1078 | The trial court did not abuse its discretion in affirming the order of the SPBR dismissing appellant’s administrative appeal from his denial of reinstatement to employment following his involuntary disability separation. | Schuster | 7/10/2014 | 2014-Ohio-3047
Dunkle v. Ohio Dept. of Rehab. & Corr. | 13AP-923 | Plaintiff's claim for breach of plea agreement against state barred by statute of limitations. | Klatt | 7/10/2014 | 2014-Ohio-3046
State v. Loel | 13AP-874 | Trial court did not err by denying motions to dismiss based on alleged violation of speedy trial rights; days between dismissal of complaint and filing of indictment did not count in speedy trial analysis because no charges were pending against him during those days. | Klatt | 7/10/2014 | 2014-Ohio-3045
State ex rel Brown v. Indus. Comm. | 13AP-763 | Objections overruled, writ denied. Commission's statement that it was granting the employer's previously denied request for reconsideration amounted to harmless error, as it was apparent that the commission was invoking its continuing jurisdiction over relator's PTD application and the commission clearly identified two mistakes of law in the SHO's order. The SHO committed clear mistakes of law by citing to two vocational reports after the SHO found relator PTD based solely on the allowed physical conditions, and by using a psychologist's report the SHO did not rely on to support the start date for the PTD compensation. | Connor | 7/10/2014 | 2014-Ohio-3044
Savoy v. Univ. of Akron | 13AP-696 | Trial court did not err by granting summary judgment on plaintiff's claims for false arrest, defamation, breach of contract, malicious prosecution and abuse of process. | Klatt | 7/10/2014 | 2014-Ohio-3043
Nour v. Shawar | 13AP-1070, 13AP-1076 | Although Nour is expressly entitled to indemnification from Shawar "for claims, expenses, liabilities, and causes of action" arising from any breach by Shawar, Nour does not have a right of indemnification for "reasonable counsel fees" because such a right is expressly granted only to Shawar. | Connor | 7/8/2014 | 2014-Ohio-3016
Foster v. Idegy, Inc. | 13AP-948 | Because both plaintiff and defendant received a judgment in their favor, each were a prevailing party for purposes of Civ.R. 54(D). The trial court did not abuse its discretion in allocating one-half of the court costs to the plaintiff. Judgment affirmed. | Sadler | 7/8/2014 | 2014-Ohio-3015
Glasstetter v. Rehab. Servs. Comm. | 13AP-932 | The common pleas court did not err in finding the order of the State Personnel Board of Review which found the board lacked jurisdiction over appellant’s administrative appeal was supported by reliable, probative and substantial evidence and in accordance with law. Appellant was not an employee in the classified service even though she was mistakenly designated as such for several years. | O'Grady | 7/8/2014 | 2014-Ohio-3014
Hastings Mut. Ins. Co. v. Village Communities Real Estate, Inc. | 14AP-35 | The trial court did not err in granting appellee’s motion for summary judgment as all of the claims occurred and were known prior to the policy dates and therefore excluded from coverage. | Luper Schuster | 6/30/2014 | 2014-Ohio-2916
State v. Bass | 13AP-1052 | Trial court did not abuse its discretion in refusing to grant a motion for new trial many years after jury verdict. | Tyack | 6/30/2014 | 2014-Ohio-2915
State v. Hughes | 13AP-1006 | Trial court did not err denying untimely petition for postconviction relief. | Klatt | 6/30/2014 | 2014-Ohio-2914
Wee Care Child Ctr., Inc. v. Ohio Dept. of Job & Family Servs. | 13AP-1004 | The Court of Claims properly denied appellants’ motion to compel discovery and request for a hearing on the immunity of state employees. The court also properly granted appellees summary judgment and determined on summary judgment that state employees had civil immunity. The central theme of appellants’ case – that appellees and their employees wrongfully conspired to put them out of business – was unsupported by the evidence. Therefore, we affirm the trial court’s judgment. | O'Grady | 6/30/2014 | 2014-Ohio-2913
State v. Thomas | 13AP-985 | Trial court did not err in revoking appellant's community control. | Brown | 6/30/2014 | 2014-Ohio-2912
State ex rel. Crawford v. Indus. Comm. | 13AP-929 | We affirm the order of the commission denying relator's application for PTD compensation. | O'Grady | 6/30/2014 | 2014-Ohio-2911
State v. Mercier | 13AP-906 | Under the plain and unambiguous language of R.C. 4511.19, the appellant’s sentence was not contrary to law. R.C. 4511.19(G)(1) expressly authorizes a court to sentence a violator of R.C. 4511.19(A)(1) up to five years of incarceration to the exclusion of Chapter 2929. of the Revised Code. Accordingly, the trial court was not required to sentence appellant under Chapter 2929. of the Revised Code and no conflict exists between the two statutes. Assignment of error is overruled and judgment affirmed. | Luper Schuster | 6/30/2014 | 2014-Ohio-2910
Foster v. Sullivan | 13AP-876 | We affirm the trial court’s judgment finding no error in the court’s decision to grant summary judgment in favor of appellees. | O'Grady | 6/30/2014 | 2014-Ohio-2909
Piepho v. Franklin Cty. Bd. of Revision | 13AP-818 | We affirm the judgment of the Board of Tax Appeals because it was not unreasonable or unlawful. | O'Grady | 6/30/2014 | 2014-Ohio-2908
Pankey v. Ohio Dept. of Rehab. & Corr. | 13AP-701 | Court of Claims did not err in granting appellee's motion to dismiss appellant's complaint. | Brown | 6/30/2014 | 2014-Ohio-2907
Luper Neidenthal & Logan v. Albany Station, L.L.C. | 13AP-651 | In foreclosure action, trial court properly granted summary judgment in favor of competing lienholders and denying summary judgment for appellant lienholder. | T. Bryant | 6/30/2014 | 2014-Ohio-2906
State v. Phipps | 13AP-640 | We reverse the trial court's judgment and remand the matter because (1) the trial court did not make the findings required by R.C. 2929.14(C)(4) before imposing consecutive sentences, and (2) the trial court did not consider applicable case law pertaining to merger of his convictions for kidnapping and aggravated robbery. However, we otherwise affirm the judgment because the trial court porperly advised appellant at the plea hearing of the maximum penalty involved as required by Crim.R. 11, and trial counsel provided effective assistance of counsel. | Klatt | 6/30/2014 | 2014-Ohio-2905
Southwestern Obstetrics & Gynecology, Inc. v. Mehta, M.D. | 13AP-624 | Physician practice sought reimbursement of alleged over-compensation paid to physician during 3 year employment term. The trial court found each party was entitled to damages on breach of contract claim. On appeal we affirmed in part and reversed in part, but unable to recalculate damages because the exhibits were incomplete. | O'Grady | 6/30/2014 | 2014-Ohio-2904
Welty v. Casper | 13AP-618; 13AP-714 | The trial court's judgment was not an abuse of discretion. | Brown | 6/30/2014 | 2014-Ohio-2903
Nix v. Ohio Dept. of Rehab. & Corr. | 13AP-547 | Trial court's determinations that two corrections officers were not entitled to immunity, and that appellant failed to prove that appellee's other employees were aware of conduct of those corrections officers, was not against the manifest weight of the evidence. | Brown | 6/30/2014 | 2014-Ohio-2902
Jones v. Roberts | 14AP-151 | Trial court did not err when it dismissed appellant's complaint based upon his failure to prosecute. | Brown | 6/26/2014 | 2014-Ohio-2798
State v. Muhammad | 14AP-143 | We affirm the trial court’s judgment because appellant did not demonstrate plain error occurred regarding how his motion was filed, or otherwise establish the trial court erred. | O'Grady | 6/26/2014 | 2014-Ohio-2797
Scott v. Ohio Dept. of Rehab. & Corr. | 14AP-98, 14AP-105, 14AP-106, 14AP-107, 14AP-108, 14AP-109, 14AP-110, 14AP-111, 14AP-112, 14AP-113 | Because the trial court was acting pursuant to a remand when it modified its judgment entry, the trial court properly exercised jurisdiction despite a pending application for reconsideration in the appellate court. Judgment affirmed. | Sadler | 6/26/2014 | 2014-Ohio-2796
Perri v. Sutphen Corp. | 14AP-91 | Evidence did not demonstrate plaintiff was fired for pursuing workers' compensation benefits. | Tyack | 6/26/2014 | 2014-Ohio-2795
Dlesk v. Ohio Dept. of Rehab. & Corr. | 14AP-16 | Sup.R. 45 does not apply to a request to restrict public access to case records in an action commenced prior to the effective date of Sup.R. 45. | Klatt | 6/26/2014 | 2014-Ohio-2794
Foreman v. Dept. of Rehab. & Corr. | 14AP-15 | Judgment affirmed. The Court of Claims of Ohio properly granted ODRC's motion to dismiss, as the Court of Claims did not possess jurisdiction to address Foreman's constitutional claims or to review a common pleas court's determination regarding jail-time credit. Foreman also failed to state a claim for false imprisonment, as he was in prison pursuant to valid orders from the Hancock County Court of Common Pleas. | Connor | 6/26/2014 | 2014-Ohio-2793
Lupo v. Columbus | 13AP-1063 | Civ.R. 12(B)(6) does not apply to R.C. 2506.01 appeals. The trial court erred by dismissing appellant's R.C. 2506.01 appeal for lack of standing without granting her the requested hearing to present evidence relevant to her contention that the administrative order would cause a diminution of her property value. | Klatt | 6/26/2014 | 2014-Ohio-2792
State ex rel. Gen. Motors Co. v. Webster | 13AP-931 | Self-insured employer was not entitled to a writ of mandamus to block payment of benefits to a widow whose husband died of mesothelioma. | Tyack | 6/26/2014 | 2014-Ohio-2791
Murray v. Columbus | 13AP-912 | Trial court did not err when it dismissed appellant's claims of fraud and civil conspiracy against appellant's employer and labor union where the allegations in the complaint establish a violation of the union's duty of fair representation under R.C. 4117.11(B)(6), as such claims are within the exclusive jurisdiction of SERB. | Connor | 6/26/2014 | 2014-Ohio-2790
State ex rel. Turner v. Dept. of Rehab. & Corr. | 13AP-911 | Respondents were entitled to Civ.R. 12(B)(6) dismissal because the existence of a plain and adequate remedy at law barred relator's request for mandamus relief. Motion to dismiss granted. | Sadler | 6/26/2014 | 2014-Ohio-2789
State v. Fair | 13AP-901 | We reverse the trial court’s judgment and remand the matter for resentencing because the court did not make the findings required by R.C. 2929.14(C)(4) before imposing consecutive sentences; however, we otherwise affirm the trial court’s judgment because appellant’s convictions were supported by sufficient evidence and the manifest weight of the evidence, the prosecutor did not commit misconduct, and the court did not err in denying appellant’s motion for a mistrial. | O'Grady | 6/26/2014 | 2014-Ohio-2788
State v. Altunar | 13AP-875 | Trial court complied with R.C. 2943.031 by providing immigration-related consequences to non-citizens before accepting guilty plea. | Klatt | 6/26/2014 | 2014-Ohio-2787
Elkins v. Ohio Dept. of Rehab. & Corr. | 13AP-856 | Trial court erred by granting summary judgment on claims for unauthorized disclosure of medical records, invasion of privacy, and intentional infliction of emotional distress. The trial court erred by relying on grounds not raised in the motion for summary judgment because appellant was denied a meaningful opportunity to respond to them. ODRC also failed to establish that reasonable minds could only come to the conclusion that it appropriately exercised its discretionary authority under the Ohio Administrative Code by releasing appellant's medical records. The Court of Claims erred by granting summary judgment on claim for invasion of privacy; the court lacked jurisdiction over this claim, but effectively exercised jurisdiction by granting summary judgment. | Dorrian | 6/26/2014 | 2014-Ohio-2786
State v. Horton | 13AP-855 | Trial court did not commit plain error with respect to verdict forms by failing to provide separate verdict forms for aggravated murder and complicity to aggravated murder because a charge of complicity may be stated as a violation of the complicity statute or in terms of the principal offense and because there was sufficient evidence to allow the jury to determine that appellant either committed the principal offense or aided and abetted the principal offense. Trial court did not commit plain error with respect to jury instructions by failing to instruct the jury that it was required to reach a unanimous verdict as to whether appellant was guilty of aggravated murder as the principal offender or as an aider and abettor; the court generally instructed the jury on the need for a unanimous verdict and appellant failed to show that, but for the alleged error, the outcome of the proceedings would clearly have been different. Appellant's claim of ineffective assistance of counsel was rejected because he failed to show that he was prejudiced by his counsel's failure to object to the verdict forms or jury instructions. | Dorrian | 6/26/2014 | 2014-Ohio-2785
State ex rel. Lawson v. Indus. Comm. | 13AP-834 | Writ denied. Because relator had an adequate remedy at law, as she could have appealed the order from the Bureau of Workers' Compensation ("BWC") denying her application to participate in the BWC fund, relator was not entitled to mandamus relief. | Connor | 6/26/2014 | 2014-Ohio-2784
Perkins v. Columbus Bd. of Edn. | 13AP-803 | Trial court properly granted judgment and pleadings in favor of defendant school superintendent, who was immune from liability. | Klatt | 6/26/2014 | 2014-Ohio-2783
State ex rel. Ritzie v. Reece-Campbell, Inc. | 13AP-669 | This original action was referred to a magistrate; this court adopted the magistrate’s decision with certain modifications and denied relator’s request for a writ of mandamus, finding no abuse of discretion in the Industrial Commission’s denial of relator’s application for temporary total disability compensation. | O'Grady | 6/26/2014 | 2014-Ohio-2782
Citizens Banking Co. v. Parsons | 11AP-480 | In construing the evidence in a light most favorable to the defendants in this action for money judgment and replevin on two promissory notes, the trial court did not err in granting summary judgment in favor of the plaintiff. Judgment affirmed. | Sadler | 6/26/2014 | 2014-Ohio-2781
Lund v. Portsmouth Local Air Agency | 14AP-60 | Order of the Environmental Rev. Appeals Comm. affirmed. | Brown | 6/24/2014 | 2014-Ohio-2741
State v. Patterson | 14AP-50, 14AP-290 | Trial court should have given a charge of aggravated assault when the defendant hit a man who he believed had solicited sex from a seven year old son of the defendant's girlfriend. The victim clearly testified the defendant was in a rage and the provocation was strong. The solicitation had occurred shortly before the injury. | Tyack | 6/24/2014 | 2014-Ohio-2740
State v. Hackett | 14AP-48 | A jury could reasonably find a defendant knowingly possessed a packet of white powder in his pants pocket and knowingly possessed a controlled substance. | Tyack | 6/24/2014 | 2014-Ohio-2739
Ross v. Columbus | 14AP-38 | Appellant who was injured when a bench collapsed at the Franklin County Municipal Court could not recover from the owner of the building, as opposed to the city of Columbus which leased the floor for court purposes. | Tyack | 6/24/2014 | 2014-Ohio-2738
State v. Williams | 13AP-992 | The trial court did not err in dismissing Counts 1, 2, and 3 of the indictment for a violation of appellee’s constitutional right to a speedy trial, but the trial court erred in dismissing Counts 4 and 5 of the indictment as appellee’s constitutional right to a speedy trial was not violated as to those counts. | Schuster | 6/24/2014 | 2014-Ohio-2737
Yohannes Parkwood, Inc. v. Ohio Liquor Control Comm. | 13AP-974 | Judgment reversed and case remanded with instructions. Trial court abused its discretion in affirming an order of the liquor control commission which affirmed a tax non-renewal order from the division of liquor control, as trial court stated that a representative from the department of taxation testified that the permit holder had an outstanding tax liability, but the record revealed that a representative from the department of taxation testified that the permit holder was current on its taxes and entitled to a full renewal of its liquor permit. Because R.C. 4303.271(D)(2)(a) states that the division shall not renew a liquor permit under that section until the division receives evidence from the tax commissioner that the tax delinquency, liability, or assessment has been resolved, and the evidence from the tax commissioner before the commission was that the permit holder's tax liability or assessment had been resolved, the commission's order was not in accordance with law. | Connor | 6/24/2014 | 2014-Ohio-2736
Hicks v. Ohio Dept. of Job & Family Servs. | 13AP-902 | The court affirmed a judgment of the Franklin County Court of Common Pleas which upheld a denial of unemployment compensation benefits by appellee Ohio Department of Job and Family Services ("ODJFS"). The court held that competent, credible evidence in the record supported the decision of ODJFS that appellant's employer had terminated her with just cause. The court also rejected two assignments of error asserting that ODJFS had failed to follow statutory procedure in (1) allowing a continuance of a hearing and (2) in failing to provide the common pleas court with a complete file of the proceedings at the agency level. | Dorrian | 6/24/2014 | 2014-Ohio-2735
In re A.J. | 13AP-864, 13AP-865 | Award of permanent custody affirmed; temporary custody did not end because Franklin County Children Services filed motion pursuant to R.C. 2151.415(A) before sunset date of custody in accordance with R.C. 2151.353(F). | Klatt | 6/24/2014 | 2014-Ohio-2734
State v. Joseph | 13AP-752, 13AP-753 | Judgment affirmed. Because defendant pled guilty to two misdemeanor violations of violating a protection order, in violation of R.C. 2919.27, R.C. 2930.14 did not apply to defendant's sentencing hearing. The trial court's decision to not allow defendant to view a statement written by the victim, prior to the court's imposition of sentence, did not deprive defendant of due process of law or his right to allocution under Crim.R. 32. | Connor | 6/24/2014 | 2014-Ohio-2733
State v. Orms | 13AP-698 | Trial court erred in failing to make required findings and listing of sentencing factors in granting appellee's motion for judicial release. | Brown | 6/24/2014 | 2014-Ohio-2732
State ex rel. Gibbs v. Thistledown, Inc. | 13AP-487 | The Industrial Commission of Ohio did not abuse its discretion in denying claimant's application for permanent total disability compensation. Writ of mandamus denied. | Sadler | 6/24/2014 | 2014-Ohio-2731
State v. Jalloh | 13AP-411 | Judgment affirmed. As defendant-appellant failed to file the transcript from the sentencing hearing, this court presumes that the trial court orally notified defendant of the consequences of violating post-release control. As such, res judicata barred defendant's arguments. | Connor | 6/24/2014 | 2014-Ohio-2730
Ander v. Clark | 14AP-65 | Trial court was premature in granting motion for dismissal through application of Civ.R. 12(B)(6). Pleadings left tentative questions about whether the statute of limitations had run because of questions about when the claim accrued. | Tyack | 6/19/2014 | 2014-Ohio-2664
Wright v. Dir., Ohio Dept. of Job & Family Servs. | 13AP-1048 | The trial court erred in affirming a decision of the Unemployment Compensation Review Commission finding appellant was ineligible for unemployment compensation. Appellant was able to perform sedentary job duties, and, therefore, was entitled to receive unemployment compensation upon being laid off by his employer. Accordingly, the unemployment benefits appellant received did not constitute an overpayment. Assignments of error sustained and judgment reversed. | Schuster | 6/19/2014 | 2014-Ohio-2663
State v. Ball | 13AP-1030 | Trial court did not err denying motion to correct sentence; res judicata barred arguments not previously raised and defendant was properly notified of post-release control. | Klatt | 6/19/2014 | 2014-Ohio-2662
State v. R.L.M. | 13AP-981 | Because, pursuant to R.C. 2953.52(A)(1), the trial court erred by granting the sealing of appellee's records without having determined whether his drug-related charges and traffic offenses arose "as a result of or in connection with the same act," we reverse the decision of the trial court. | Dorrian | 6/19/2014 | 2014-Ohio-2661
Lawton v. Howard | 13AP-878 | Because the trial court properly dismissed appellant's complaint pursuant to Civ.R. 12(B)(1) or, in the alternative, pursuant to Civ.R. 12(B)(6), we affirm the decision of the trial court. | Dorrian | 6/19/2014 | 2014-Ohio-2660
State v. Agbohla | 13AP-839 | No error in denying the defendant's motion to suppress where parole officer had reasonable suspicion to conduct a warrantless search of a parolee. Judgment affirmed. | Sadler | 6/19/2014 | 2014-Ohio-2659
Dalton v. Ohio Dept. Rehab. & Corr. | 13AP-827 | Judgment affirmed. Dalton failed to establish a prima facie case of perceived disability discrimination under R.C. 4112.02, as ODRC's act of sending Dalton to an independent medical examination, following Dalton's odd conduct, did not amount to evidence that ODRC perceived Dalton as disabled. ODRC also complied with Ohio Adm.Code 123:1-30-03 in sending Dalton to the examination. No genuine issue of material fact existed regarding Dalton's claims for invasion of privacy. | Connor | 6/19/2014 | 2014-Ohio-2658
Martin v. Giant Eagle, Inc. | 13AP-809 | In construing the evidence in a light most favorable to appellant in this premises liability case, the trial court properly granted summary judgment in favor of appellees. The judgment of the trial court is affirmed. | Sadler | 6/19/2014 | 2014-Ohio-2657
State v. Burney | 14AP-354, 14AP-356 | Trial court did not abuse its discretion when it denied bail to appellants where the State had proven, by clear and convincing evidence, that appellants committed the offenses with which they were charged, that appellants pose a substantial risk of serious physical harm to the community, and that there are no release conditions which will reasonably assure the safety of appellants and the community. | Connor | 6/17/2014 | 2014-Ohio-2622
State v. C.A. | 13AP-982, 13AP-1001 | The court reversed two judgments of the Franklin County Municipal Court sealing the records of drug-related charges filed against appellee that were ultimately dismissed. The court followed the decision of the Supreme Court of Ohio in State v. Pariag, 137 Ohio St.3d 81, 2013-Ohio-4010, which held that a trial court may not seal the record of a dismissed charge if the dismissed charge "arises as the result of or in connection with the same act" associated with a non-sealable conviction. The court remanded the case to the municipal court with instructions that it determine whether appellee's drug-related charges and her non-sealable traffic offense (operating a vehicle while under the influence of alcohol) arose "as a result of or in connection with the same act." | Dorrian | 6/17/2014 | 2014-Ohio-2621
State v. Mossman | 13AP-959 | Appellant was charged with operating a vehicle while under the influence of alcohol. The court of appeals reversed a judgment entered by the Franklin County Court of Common Pleas suppressing evidence obtained subsequent to a traffic stop and remanded the case for further proceedings. The court of appeals found that the state trooper, who clocked appellant driving well in excess of the speed limit, was justified in stopping appellant. The trial court, however, used an incorrect standard in determining whether the officer legally detained appellant for the purpose of conducting field sobriety tests. The state was only required to determine whether the facts demonstrated a basis for reasonable suspicion of impaired driving—the state was not required to establish probable cause. The court of appeals found that there was a basis for reasonable suspicion of drunk driving on the facts presented at the suppression hearing. It remanded the case for the trial court to determine whether, following the field sobriety testing, probable cause existed to justify appellant's arrest. | Dorrian | 6/17/2014 | 2014-Ohio-2620
Cotten v. Ohio Dept. of Rehab. & Corr. | 13AP-935 | The Court of Claims lacked subject-matter jurisdiction over the asserted Section 1983 claims and therefore did not err by dismissing complaint for lack of jurisdiction. The complaint did not contain sufficient allegations to establish state law claims for intentional infliction of emotional distress or invasion of privacy. | Dorrian | 6/17/2014 | 2014-Ohio-2619
State v. V.J. | 13AP-799 | The trial court did not abuse its discretion in granting the prosecution's motion to amend the indictment to delete language pertaining to specifications alleging appellant was a repeat violent offender. Additionally, the defendant's convictions were not against the manifest weight of the evidence. However, because the trial court failed to make the required findings before the imposition of consecutive sentences, the matter was remanded for resentencing. Judgment affirmed in part and reversed in part. | Sadler | 6/17/2014 | 2014-Ohio-2618
Doe v. Vineyard Columbus | 13AP-599 | Vineyard Columbus filed a motion to stay and compel arbitration. The trial court found no agreement to arbitrate occurred. We affirmed. | Connor | 6/17/2014 | 2014-Ohio-2617
State ex rel. Armstrong Steel Erectors, Inc. v. Indus. Comm. | 13AP-190 | The Industrial Commission of Ohio did not abuse its discretion in granting claimant's application for an additional award for violation of a specific safety requirement. Writ of mandamus denied. | Sadler | 6/17/2014 | 2014-Ohio-2616
State ex rel. Smoot v. KBO Inc. | 13AP-903 | Some evidence supported the Industrial Commission’s denial of permanent total disability compensation. | Tyack | 6/12/2014 | 2014-Ohio-2543

Page: [ 1] 2 3 4 next